@@ -18,17 +18,20 @@
 
 #include <QSplitter>
 
-class Q3WidgetStack;
+class QStackedWidget;
 
 class Playlist;
 class SearchWidget;
 class PlaylistInterface;
 class TagEditor;
 class PlaylistBox;
+class NowPlaying;
+class PlayerManager;
+class FileHandle;
 
 /**
  * This is the main layout class of JuK.  It should contain a PlaylistBox and
- * a QWidgetStack of the Playlists.
+ * a QStackedWidget of the Playlists.
  *
  * This class serves as a "mediator" (see "Design Patterns") between the JuK
  * class and the playlist classes.  Thus all access to the playlist classes from
@@ -40,13 +43,21 @@ class PlaylistSplitter : public QSplitter
     Q_OBJECT
 
 public:
-    explicit PlaylistSplitter(QWidget *parent, const char *name = 0);
+    PlaylistSplitter(PlayerManager *player, QWidget *parent);
     virtual ~PlaylistSplitter();
 
     PlaylistInterface *playlist() const;
 
     virtual bool eventFilter(QObject *watched, QEvent *event);
 
+signals:
+    /**
+     * Emitted when GUI is created and the cache is loaded.  Is kind of a hack
+     * until we move the time-intensive parts to a separate thread but then
+     * again at least this works.
+     */
+    void guiReady();
+
 public slots:
     virtual void setFocus();
     virtual void slotFocusCurrentPlaylist();
@@ -56,7 +67,7 @@ private:
 
     /**
      * This returns a pointer to the first item in the playlist on the top
-     * of the QWidgetStack of playlists.
+     * of the QStackedWidget of playlists.
      */
     Playlist *visiblePlaylist() const;
 
@@ -73,14 +84,16 @@ private slots:
      */
     void slotShowSearchResults();
     void slotPlaylistSelectionChanged();
-    void slotPlaylistChanged(QWidget *w);
+    void slotPlaylistChanged(int i);
 
 private:
     Playlist *m_newVisible;
     PlaylistBox *m_playlistBox;
     SearchWidget *m_searchWidget;
-    Q3WidgetStack *m_playlistStack;
+    QStackedWidget *m_playlistStack;
     TagEditor *m_editor;
+    NowPlaying *m_nowPlaying;
+    PlayerManager *m_player;
 };
 
 #endif
