@@ -13,19 +13,28 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "splashscreen.h"
+
 #include <kapplication.h>
 #include <kiconloader.h>
 #include <klocale.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 
-#include <qlabel.h>
-
-#include "splashscreen.h"
+#include <QPixmap>
+#include <QLabel>
+#include <QPalette>
 
 SplashScreen *SplashScreen::splash = 0;
 bool SplashScreen::done = false;
 int SplashScreen::count = 0;
 
+static QString loadedText(int i)
+{
+    static QString loading = i18n("Loading").toUpper();
+    return loading + ": " + QString::number(i);;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // pubic members
 ////////////////////////////////////////////////////////////////////////////////
@@ -63,39 +72,26 @@ void SplashScreen::update()
 // protected members
 ////////////////////////////////////////////////////////////////////////////////
 
-SplashScreen::SplashScreen() : QHBox(0 , "splashScreen", Qt::WStyle_Splash)
+SplashScreen::SplashScreen() : QLabel(0, Qt::WStyle_Splash)
 {
-    setMargin(10);
-    setSpacing(5);
+    setObjectName("splashScreen");
 
-    setLineWidth(5);
-    setFrameShape(Box);
-    setFrameShadow(Plain);
+    QPixmap background = UserIcon("splash");
+    resize(background.size());
+    QPalette palette;
+    palette.setBrush(backgroundRole(), QBrush(background));
 
-    QFont font = QWidget::font();
+    setMargin(7);
+    setAlignment(Qt::AlignLeft | Qt::AlignBottom);
 
-    if(font.pixelSize() > 0)
-        font.setPixelSize(font.pixelSize() * 2);
-    else
-        font.setPointSize(font.pointSize() * 2);
+    palette.setColor(foregroundRole(), QColor(107, 158, 194));
+    setPalette(palette);
 
-    QLabel *iconLabel = new QLabel(this);
-    iconLabel->setPixmap(DesktopIcon("juk"));
+    QFont f = font();
+    f.setPixelSize(10);
+    setFont(f);
 
-    QLabel *textLabel = new QLabel(i18n("Items loaded:"), this);
-    textLabel->setFont(font);
-
-    m_countLabel = new QLabel(this);
-    m_countLabel->setText(QString::number(count));
-    m_countLabel->setFont(font);
-    m_countLabel->setMinimumWidth(m_countLabel->fontMetrics().width("00000"));
-
-    setMaximumWidth(iconLabel->width() + textLabel->width() + m_countLabel->width() + 10);
-    setMaximumHeight(QMAX(iconLabel->height(), textLabel->height()));
-
-    QDesktopWidget *desktop = KApplication::desktop();
-    QRect r = desktop->screenGeometry(desktop->primaryScreen());
-    setGeometry((r.width() / 2) - (width() / 2), (r.height() / 2) - (height() / 2), width(), height());
+    setText(loadedText(0));
 }
 
 SplashScreen::~SplashScreen()
@@ -109,6 +105,8 @@ SplashScreen::~SplashScreen()
 
 void SplashScreen::processEvents()
 {
-    m_countLabel->setText(QString::number(count));
+    setText(loadedText(count));
     kapp->processEvents();
 }
+
+// vim: set et sw=4 tw=0 sta:
