@@ -25,7 +25,6 @@
 #include "libkcddb/sites.h"
 #include "libkcddb/lookup.h"
 
-#include <q3listbox.h>
 #include <qlist.h>
 #include <kfiledialog.h>
 #include <kapplication.h>
@@ -33,9 +32,7 @@
 #include <kinputdialog.h>
 #include <kmessagebox.h>
 #include <keditlistbox.h>
-#include <q3widgetstack.h>
 #include <kurlrequester.h>
-#include <q3buttongroup.h>
 #include <QCheckBox>
 
 CDDBConfigWidget::CDDBConfigWidget(QWidget * parent)
@@ -53,10 +50,9 @@ CDDBConfigWidget::CDDBConfigWidget(QWidget * parent)
   urlReq->setMode(KFile::Directory);
 
   KEditListBox* editListBox = new KEditListBox(i18n("Cache Locations"), urlReq->customEditor(), cacheLocationsParent, "kcfg_cacheLocations");
-  cacheLocationsParent->addWidget(editListBox);
-  cacheLocationsParent->setCurrentWidget(editListBox);
-
-  kcfg_FreedbSubmitTransport->remove(needsAuthenticationBox);
+  QHBoxLayout *layout = new QHBoxLayout(cacheLocationsParent);
+  layout->setMargin(0);
+  layout->addWidget(editListBox);
 
   connect(needsAuthenticationBox,SIGNAL(toggled(bool)),SLOT(needAuthenticationChanged(bool)));
   connect(kcfg_FreedbLookupTransport,SIGNAL(activated(int)),SLOT(protocolChanged()));
@@ -68,9 +64,9 @@ void CDDBConfigWidget::showMirrorList()
 {
     KCDDB::Sites s;
 
-    QList<KCDDB::Mirror> sites = s.siteList();
+    const QList<KCDDB::Mirror> sites = s.siteList();
     QMap<QString, KCDDB::Mirror> keys;
-    for (QList<KCDDB::Mirror>::Iterator it = sites.begin(); it != sites.end(); ++it)
+    for (QList<KCDDB::Mirror>::ConstIterator it = sites.begin(); it != sites.end(); ++it)
       if ((*it).transport == KCDDB::Lookup::CDDBP)
         keys[(*it).address + "(CDDBP, " + QString::number((*it).port) + ") " + (*it).description] = *it;
       else
